You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@commons.apache.org by mb...@apache.org on 2009/03/09 22:32:24 UTC

svn commit: r751849 - /commons/proper/collections/branches/collections_jdk5_branch/src/java/org/apache/commons/collections/OrderedIterator.java

Author: mbenson
Date: Mon Mar  9 21:32:22 2009
New Revision: 751849

URL: http://svn.apache.org/viewvc?rev=751849&view=rev
Log:
comment

Modified:
    commons/proper/collections/branches/collections_jdk5_branch/src/java/org/apache/commons/collections/OrderedIterator.java

Modified: commons/proper/collections/branches/collections_jdk5_branch/src/java/org/apache/commons/collections/OrderedIterator.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/branches/collections_jdk5_branch/src/java/org/apache/commons/collections/OrderedIterator.java?rev=751849&r1=751848&r2=751849&view=diff
==============================================================================
--- commons/proper/collections/branches/collections_jdk5_branch/src/java/org/apache/commons/collections/OrderedIterator.java (original)
+++ commons/proper/collections/branches/collections_jdk5_branch/src/java/org/apache/commons/collections/OrderedIterator.java Mon Mar  9 21:32:22 2009
@@ -5,9 +5,9 @@
  * The ASF licenses this file to You under the Apache License, Version 2.0
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
- * 
+ *
  *      http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -17,10 +17,11 @@
 package org.apache.commons.collections;
 
 import java.util.Iterator;
+import java.util.ListIterator;
 import java.util.NoSuchElementException;
 
 /**
  * Defines an iterator that operates over an ordered container.
  * <p>
  * This iterator allows both forward and reverse iteration through the container.
  *
@@ -17,10 +17,11 @@
 
 /**
- * Defines an iterator that operates over an ordered container.
+ * Defines an iterator that operates over an ordered container. Subset of {@link ListIterator}.
  * <p>
  * This iterator allows both forward and reverse iteration through the container.